# apoplast

# platform # stack # app # cyte # harbor # microservice # toughie # hully

Like a fortress or dyson sphere, the paths within the scales start to appear.

`ports: mongo: 39000 sanic: 8000 help: 20000`

## install

`[prompt] pip install apoplast # # apoplast uses "sanic" command line, # and, if local, the "mongod" command line. #`

## essence

`''' /apoplast_frame /monetary /_data the.process_identity_number the.logs /harbor the.process_identity_number ''' import json fp = open ("/online/vaccines_apoplast/mints/apoplast/ellipsis.JSON", "r") ellipsis = json.loads (fp.read ()) fp.close () def crate (the_path): from os.path import dirname, join, normpath import sys import pathlib this_directory = pathlib.Path (__file__).parent.resolve () return str (normpath (join (this_directory, the_path))) essence = { "monetary": { "DB_name": "ingredients", "URL": "mongodb://0.0.0.0:39000/", "onsite": { "host": "0.0.0.0", "port": "39000", "path": crate ("monetary/_data"), "PID_path": crate ("monetary/the.process_identity_number"), "logs_path": crate ("monetary/the.logs") }, "saves": { "path": crate ("monetary/_saves") } }, "harbor": { "PID_path": crate ("harbor/the.logs") }, "USDA": { "food": ellipsis ["USDA"] ["food"] }, "NIH": { "supp": ellipsis ["NIH"] ["supp"] } }`

## on

This turns on mongo and sanic

`[prompt] apoplast on # # This does this: # # [prompt] apoplast on --essence-path essence.py #` `import apoplast._interfaces.on as apoplast_on apoplast_on.on ( essence_path = "essence.py" )`

## off

This turns off mongo and sanic

`[prompt] apoplast off # # This does this: # # [prompt] apoplast off --essence-path essence.py #` `import apoplast._interfaces.off as apoplast_off apoplast_off.off ( essence_path = "essence.py" )`

## import

This adds the documents to mongo

`[prompt] apoplast monetary structures import --import-name export.1.json` `import apoplast._interfaces.on as apoplast_on apoplast_on.on ( essence_path = "essence.py" )`

## locations

`[get] /docs [get] /docs/swagger`

This adds the documents to mongo

`[get] /USDA/food/FDC_ID/2369390`

## data nodes

monetary mongo: DB:ingredients collection:essential_nutrients collection:cautionary_ingredients

## groceries

## foods

"clouds/food_USDA"

## supps

"clouds/supp_NIH"